"""ECG waveform for Android"""
__copyright__ = '(c) 2011 Emant Pte Ltd'
__license__ = 'Apache License, Version 2.0'
__version__ = '0.11.1230'

import android
import json
import math

import emant
import peakdetect

droid = android.Android()
droid.webViewShow('file:///sdcard/sl4a/scripts/graph.html')

MAINS_FREQ = 50
NOTCH_LENGTH_AVERAGE = 4
ScanRate = MAINS_FREQ * NOTCH_LENGTH_AVERAGE
NumSamples = ScanRate * 2 + NOTCH_LENGTH_AVERAGE 

def NotchMains(ECGdata):
    filteredECG=[]
    for i in range(len(ECGdata)-NOTCH_LENGTH_AVERAGE):
        filteredECG.append((sum(ECGdata[i:(i+NOTCH_LENGTH_AVERAGE)])/NOTCH_LENGTH_AVERAGE))
    return filteredECG

def format4Flot(myData):
    proData=[]
    for i in range(len(myData)):
        proData.append([i/float(ScanRate),myData[i]])
    return proData
                    
m = emant.Emant300()
m.Open()
r,actScanRate = m.ConfigAnalog(1, emant.Emant300.Bipolar, ScanRate)


loop=True
reading=[]
shr="none"

while loop:
    e = droid.eventWaitFor('check').result
    if (e['data']=='timer'):
        # read waveform
        ECGdata = m.ReadAnalogWaveform(emant.Emant300.AIN2,emant.Emant300.AIN3, NumSamples)
        reading = NotchMains(ECGdata)
        # calculate heart rate
        try:
            thresh = (max(reading)-min(reading))/2
            maxlist, minlist = peakdetect.peakdet(reading,thresh)
            ym = map(list,zip(*maxlist))
            if len(ym[0])>=2:
                diff=[]
                for i in range(len(ym[0])-1):
                    diff.append(ym[0][i+1]-ym[0][i])
                hr = sum(diff)/len(diff)
                shr = str(ScanRate*60/hr)
            else:
                shr = "none"
        except IndexError:
            shr = "none"
        # display results
        data={}
        data['hr']=shr
        data['wf']=format4Flot(reading)
        droid.eventPost("respond",json.dumps(data))
    else:
        droid.makeToast(e['data'])
        loop = not(e['data']=="quit")

m.Close()

     

